#version 300 es
precision highp int;
precision highp float;

in float vAngle;
in float vTransparency;
in float vScale;

uniform sampler2D uColorTexture;
layout(location = 0) out vec4 fColor;

void main()
{
    float cosAngle = cos(radians(vAngle));
    float sinAngle = sin(radians(vAngle));

    vec2 pointCoord = gl_PointCoord - vec2(0.5);
    vec2 scaledPointCoord = vec2(pointCoord.x / vScale, pointCoord.y / vScale);
    vec2 rotatedPointCoord = vec2(scaledPointCoord.x * cosAngle - scaledPointCoord.y * sinAngle, scaledPointCoord.x * sinAngle + scaledPointCoord.y * cosAngle) + vec2(0.5);

    vec4 texColor = texture(uColorTexture, vec2(rotatedPointCoord));
    float alpha = texColor[3];

    if(alpha <= 0.0 || vTransparency <= 0.0 || vScale <= 0.0)
    {
        discard;
        return;
    }

    vec2 outOfBounds = (vec2(1.0) - step(vec2(0.0), rotatedPointCoord))
                     + (vec2(1.0) - step(rotatedPointCoord, vec2(1.0)));
    alpha *= (1.0 - sign(outOfBounds[0] + outOfBounds[1])) * vTransparency;
    fColor = texColor;
    fColor[3] = alpha;
}
