#version 330
precision highp int;
precision highp float;
in vec4 vPosition;
in vec4 vColorOrTexCoord;
layout(location = 0) out vec4 fColor;
layout(location = 1) out vec4 fBlurNormalColor;
uniform mat4 uMMatrix;
uniform sampler2D uColorTexture;

uniform int uExistsNormal;
uniform sampler2D uNormalTexture;
//模糊
uniform int uBlurRadius;

vec4 blur(int aRadius, sampler2D aTexture, vec2 aTextureCoord)
{
    const float Pi = 3.1415f;
    const float E = 2.7182f;
    float _2R2 = 2.0f * float(aRadius * aRadius);
    float _2PiR2 = _2R2 * Pi;
    int sampleSize = aRadius * 2 + 1;
    float totalWeight = 0.0f;
    {
        for (int top = sampleSize - 1; top >= 0; top--)
        {
            float powY = pow(float(top - aRadius), 2.0f);
            for (int left = sampleSize - 1; left >= 0; left--)
            {
                float powX = pow(float(left - aRadius), 2.0f);
                totalWeight += pow(E, -float(powX + powY) / _2R2) / _2PiR2;
            }
        }
    }

    vec4 blurTexColor = vec4(0.0f);
    vec2 size = vec2(textureSize(aTexture, 0));
    float xRate = 1.0f / size.x;
    float yRate = 1.0f / size.y;
    vec2 offset = vec2(aTextureCoord.x - xRate * float(aRadius), aTextureCoord.y - yRate * float(aRadius));
    for (int top = sampleSize - 1; top >= 0; top--)
    {
        float powY = pow(float(top - aRadius), 2.0f);
        for (int left = sampleSize - 1; left >= 0; left--)
        {
            float powX = pow(float(left - aRadius), 2.0f);
            float weight = pow(E, -float(powX + powY) / _2R2) / _2PiR2 / totalWeight;
            blurTexColor += texture(aTexture, offset) * weight;

            offset.x += xRate;
        }

        offset.x = aTextureCoord.x - xRate * float(aRadius);
        offset.y += yRate;
    }

    return blurTexColor;
}

void main()
{
    //模糊图片
    fColor = blur(uBlurRadius, uColorTexture, vec2(vColorOrTexCoord));
    fBlurNormalColor = uExistsNormal == 1 ? blur(uBlurRadius, uNormalTexture, vec2(vColorOrTexCoord)) : vec4(0);
}
